@@ -552,17 +552,21 @@ class ImageMixin:
     def SetImage(self, url: URL, WidthMax: int, HeightMax: int): ...
 
     @overload
-    def SetImage(self, path: Union[str, bytes, FilePath]): ...
+    def SetImage(self, path: Union[str, bytes, FilePath, Enum]): ...
     @overload
-    def SetImage(self, path: Union[str, bytes, FilePath], WidthMax: int, HeightMax: int): ...
+    def SetImage(self, path: Union[str, bytes, FilePath, Enum], WidthMax: int, HeightMax: int): ...
 
     @overload
-    def SetImage(self, base64data: Union[str, bytes]): ...
+    def SetImage(self, base64data: Union[str, bytes, Enum]): ...
     @overload
-    def SetImage(self, base64data: Union[str, bytes], WidthMax: int, HeightMax: int): ...
+    def SetImage(self, base64data: Union[str, bytes, Enum], WidthMax: int, HeightMax: int): ...
 
 
-    def SetImage(self, data: Union[str, bytes, FilePath, URL, PhotoImage], WidthMax: int = None, HeightMax: int = None):
+    def SetImage(self, data: Union[str, bytes, Enum, FilePath, URL, PhotoImage], WidthMax: int = None, HeightMax: int = None):
+        if data is None: return self.configure(image=None)
+
+        if isinstance(data, Enum): data = data.value
+
         if isinstance(data, PhotoImage):
             return self._setImage(data)
 
